==> steamio-0.5.1-py3-none-any.whl: steam/protobufs/protobufs.py <==
# -*- coding: utf-8 -*-

from . import (
    steammessages_base,
    steammessages_clientserver,
    steammessages_clientserver_2,
    steammessages_clientserver_friends,
    steammessages_clientserver_login,
)
from .emsg import *

__all__ = ("PROTOBUFS",)


PROTOBUFS = {
    EMsg.Multi: steammessages_base.CMsgMulti,
    EMsg.ClientHeartBeat: steammessages_clientserver_login.CMsgClientHeartBeat,
    EMsg.ClientLogOff: steammessages_clientserver_login.CMsgClientLogOff,
    EMsg.ClientConnectionStats: steammessages_clientserver.CMsgClientConnectionStats,
    EMsg.ClientRemoveFriend: steammessages_clientserver_friends.CMsgClientRemoveFriend,
    EMsg.ClientChangeStatus: steammessages_clientserver_friends.CMsgClientChangeStatus,
    EMsg.ClientFriendMsg: steammessages_clientserver_friends.CMsgClientFriendMsg,
    EMsg.ClientRedeemGuestPass: steammessages_clientserver_2.CMsgClientRedeemGuestPass,
    EMsg.ClientGamesPlayed: steammessages_clientserver.CMsgClientGamesPlayed,
    EMsg.ClientRegisterKey: steammessages_clientserver_2.CMsgClientRegisterKey,
    EMsg.ClientPurchaseWithMachineID: steammessages_clientserver_2.CMsgClientPurchaseWithMachineID,
    EMsg.ClientLogOnResponse: steammessages_clientserver_login.CMsgClientLogonResponse,
    EMsg.ClientLoggedOff: steammessages_clientserver_login.CMsgClientLoggedOff,
    EMsg.ClientPurchaseResponse: steammessages_clientserver_2.CMsgClientPurchaseResponse,
    EMsg.ClientPersonaState: steammessages_clientserver_friends.CMsgClientPersonaState,
    EMsg.ClientFriendsList: steammessages_clientserver_friends.CMsgClientFriendsList,
    EMsg.ClientAccountInfo: steammessages_clientserver_login.CMsgClientAccountInfo,
    EMsg.GSStatusReply: steammessages_clientserver.CMsgGSStatusReply,
    EMsg.ClientGameConnectTokens: steammessages_clientserver.CMsgClientGameConnectTokens,
    EMsg.ClientLicenseList: steammessages_clientserver.CMsgClientLicenseList,
    EMsg.ClientCMList: steammessages_clientserver.CMsgClientCMList,
    EMsg.ClientAddFriend: steammessages_clientserver_friends.CMsgClientAddFriend,
    EMsg.ClientAddFriendResponse: steammessages_clientserver_friends.CMsgClientAddFriendResponse,
    EMsg.ClientChatInvite: steammessages_clientserver.CMsgClientChatInvite,
    EMsg.ClientRequestFriendData: steammessages_clientserver_friends.CMsgClientRequestFriendData,
    EMsg.ClientGetUserStats: steammessages_clientserver.CMsgClientGetUserStats,
    EMsg.ClientGetUserStatsResponse: steammessages_clientserver.CMsgClientGetUserStatsResponse,
    EMsg.ClientStoreUserStats: steammessages_clientserver.CMsgClientStoreUserStats,
    EMsg.ClientStoreUserStatsResponse: steammessages_clientserver.CMsgClientStoreUserStatsResponse,
    EMsg.ClientClanState: steammessages_clientserver.CMsgClientClanState,
    EMsg.ClientServiceModule: steammessages_clientserver_2.CMsgClientServiceModule,
    EMsg.ClientServiceCall: steammessages_clientserver_2.CMsgClientServiceCall,
    EMsg.ClientServiceCallResponse: steammessages_clientserver_2.CMsgClientServiceCallResponse,
    EMsg.ClientGetAppOwnershipTicket: steammessages_clientserver.CMsgClientGetAppOwnershipTicket,
    EMsg.ClientGetAppOwnershipTicketResponse: steammessages_clientserver.CMsgClientGetAppOwnershipTicketResponse,
    EMsg.ClientUpdateUserGameInfo: steammessages_clientserver_2.CMsgClientUpdateUserGameInfo,
    EMsg.ClientTicketAuthComplete: steammessages_clientserver.CMsgClientTicketAuthComplete,
    EMsg.ClientIsLimitedAccount: steammessages_clientserver.CMsgClientIsLimitedAccount,
    EMsg.ClientAuthList: steammessages_clientserver.CMsgClientAuthList,
    EMsg.ClientGetDepotDecryptionKey: steammessages_clientserver_2.CMsgClientGetDepotDecryptionKey,
    EMsg.ClientGetDepotDecryptionKeyResponse: steammessages_clientserver_2.CMsgClientGetDepotDecryptionKeyResponse,
    EMsg.ClientToGC: steammessages_clientserver_2.CMsgGcClient,
    EMsg.ClientFromGC: steammessages_clientserver_2.CMsgGcClient,
    EMsg.ClientEmailAddrInfo: steammessages_clientserver_2.CMsgClientEmailAddrInfo,
    EMsg.ClientNewLoginKey: steammessages_clientserver_login.CMsgClientNewLoginKey,
    EMsg.ClientNewLoginKeyAccepted: steammessages_clientserver_login.CMsgClientNewLoginKeyAccepted,
    EMsg.ClientStoreUserStats2: steammessages_clientserver.CMsgClientStoreUserStats2,
    EMsg.ClientStatsUpdated: steammessages_clientserver.CMsgClientStatsUpdated,
    EMsg.ClientLogon: steammessages_clientserver_login.CMsgClientLogon,
    EMsg.ClientGetClientDetails: steammessages_clientserver.CMsgClientGetClientDetails,
    EMsg.ClientGetClientDetailsResponse: steammessages_clientserver.CMsgClientGetClientDetailsResponse,
    EMsg.ClientReportOverlayDetourFailure: steammessages_clientserver.CMsgClientReportOverlayDetourFailure,
    EMsg.ClientGetClientAppList: steammessages_clientserver.CMsgClientGetClientAppList,
    EMsg.ClientGetClientAppListResponse: steammessages_clientserver.CMsgClientGetClientAppListResponse,
    EMsg.ClientInstallClientApp: steammessages_clientserver.CMsgClientInstallClientApp,
    EMsg.ClientInstallClientAppResponse: steammessages_clientserver.CMsgClientInstallClientAppResponse,
    EMsg.ClientUninstallClientApp: steammessages_clientserver.CMsgClientUninstallClientApp,
    EMsg.ClientUninstallClientAppResponse: steammessages_clientserver.CMsgClientUninstallClientAppResponse,
    EMsg.ClientSetClientAppUpdateState: steammessages_clientserver.CMsgClientSetClientAppUpdateState,
    EMsg.ClientSetClientAppUpdateStateResponse: steammessages_clientserver.CMsgClientSetClientAppUpdateStateResponse,
    EMsg.ClientWalletInfoUpdate: steammessages_clientserver.CMsgClientWalletInfoUpdate,
    EMsg.ClientFriendProfileInfo: steammessages_clientserver_friends.CMsgClientFriendProfileInfo,
    EMsg.ClientFriendProfileInfoResponse: steammessages_clientserver_friends.CMsgClientFriendProfileInfoResponse,
    EMsg.ClientGetCDNAuthToken: steammessages_clientserver_2.CMsgClientGetCdnAuthToken,
    EMsg.ClientGetCDNAuthTokenResponse: steammessages_clientserver_2.CMsgClientGetCdnAuthTokenResponse,
    EMsg.ClientRequestAccountData: steammessages_clientserver_2.CMsgClientRequestAccountData,
    EMsg.ClientRequestAccountDataResponse: steammessages_clientserver_2.CMsgClientRequestAccountDataResponse,
    EMsg.ClientHideFriend: steammessages_clientserver_friends.CMsgClientHideFriend,
    EMsg.ClientFriendsGroupsList: steammessages_clientserver_friends.CMsgClientFriendsGroupsList,
    EMsg.ClientGetClanActivityCounts: steammessages_clientserver_2.CMsgClientGetClanActivityCounts,
    EMsg.ClientGetClanActivityCountsResponse: steammessages_clientserver_2.CMsgClientGetClanActivityCountsResponse,
    EMsg.ClientLogonGameServer: steammessages_clientserver_login.CMsgClientLogon,
    EMsg.ClientItemAnnouncements: steammessages_clientserver_2.CMsgClientItemAnnouncements,
    EMsg.ClientRequestItemAnnouncements: steammessages_clientserver_2.CMsgClientRequestItemAnnouncements,
    EMsg.ClientCommentNotifications: steammessages_clientserver_2.CMsgClientCommentNotifications,
    EMsg.ClientRequestCommentNotifications: steammessages_clientserver_2.CMsgClientRequestCommentNotifications,
    EMsg.ClientFriendUserStatusPublished: steammessages_clientserver_2.CMsgClientFriendUserStatusPublished,
    EMsg.ClientCurrentUIMode: steammessages_clientserver_2.CMsgClientUiMode,
    EMsg.ClientVanityURLChangedNotification: steammessages_clientserver_2.CMsgClientVanityUrlChangedNotification,
    EMsg.ClientUserNotifications: steammessages_clientserver_2.CMsgClientUserNotifications,
    EMsg.BadgeCraftedNotification: steammessages_clientserver_2.CMsgBadgeCraftedNotification,
    EMsg.ClientNetworkingMobileCertRequest: steammessages_clientserver.CMsgClientNetworkingMobileCertRequest,
    EMsg.ClientGMSServerQuery: steammessages_clientserver_2.CMsgClientGmsServerQuery,
    EMsg.GMSClientServerQueryResponse: steammessages_clientserver_2.CMsgGmsClientServerQueryResponse,
    EMsg.GameServerOutOfDate: steammessages_clientserver_2.CMsgGameServerOutOfDate,
    EMsg.ClientInviteToGame: steammessages_clientserver.CMsgClientInviteToGame,
    EMsg.ClientRichPresenceUpload: steammessages_clientserver_2.CMsgClientRichPresenceUpload,
    EMsg.ClientRichPresenceRequest: steammessages_clientserver_2.CMsgClientRichPresenceRequest,
    EMsg.ClientRichPresenceInfo: steammessages_clientserver_2.CMsgClientRichPresenceInfo,
    EMsg.ClientChatOfflineMessageNotification: steammessages_clientserver_2.CMsgClientOfflineMessageNotification,
    EMsg.ClientChatGetFriendMessageHistory: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistory,
    EMsg.ClientChatGetFriendMessageHistoryResponse: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistoryResponse,
    EMsg.ClientChatGetFriendMessageHistoryForOfflineMessages: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistoryForOfflineMessages,
    EMsg.ClientFSGetFriendsSteamLevels: steammessages_clientserver_2.CMsgClientFsGetFriendsSteamLevels,
    EMsg.ClientFSGetFriendsSteamLevelsResponse: steammessages_clientserver_2.CMsgClientFsGetFriendsSteamLevelsResponse,
    EMsg.ClientPICSChangesSinceRequest: steammessages_clientserver.CMsgClientPICSChangesSinceRequest,
    EMsg.ClientPICSChangesSinceResponse: steammessages_clientserver.CMsgClientPICSChangesSinceResponse,
    EMsg.ClientPICSProductInfoRequest: steammessages_clientserver.CMsgClientPICSProductInfoRequest,
    EMsg.ClientPICSProductInfoResponse: steammessages_clientserver.CMsgClientPICSProductInfoResponse,
    EMsg.ClientPICSAccessTokenRequest: steammessages_clientserver.CMsgClientPICSAccessTokenRequest,
    EMsg.ClientPICSAccessTokenResponse: steammessages_clientserver.CMsgClientPICSAccessTokenResponse,
    EMsg.ClientGetEmoticonList: steammessages_clientserver_friends.CMsgClientGetEmoticonList,
    EMsg.ClientEmoticonList: steammessages_clientserver_friends.CMsgClientEmoticonList,
    EMsg.ClientPlayingSessionState: steammessages_clientserver_2.CMsgClientPlayingSessionState,
    EMsg.ClientKickPlayingSession: steammessages_clientserver_2.CMsgClientKickPlayingSession,
    EMsg.ClientServerTimestampRequest: steammessages_clientserver_login.CMsgClientServerTimestampRequest,
    EMsg.ClientServerTimestampResponse: steammessages_clientserver_login.CMsgClientServerTimestampResponse,
}

==> steamio-0.6.0-py3-none-any.whl: steam/protobufs/protobufs.py <==
# -*- coding: utf-8 -*-

from . import (
    steammessages_base,
    steammessages_clientserver,
    steammessages_clientserver_2,
    steammessages_clientserver_friends,
    steammessages_clientserver_login,
)
from .emsg import *

__all__ = ("PROTOBUFS",)


PROTOBUFS = {
    EMsg.Multi: steammessages_base.CMsgMulti,
    EMsg.ClientHeartBeat: steammessages_clientserver_login.CMsgClientHeartBeat,
    EMsg.ClientLogOff: steammessages_clientserver_login.CMsgClientLogOff,
    EMsg.ClientConnectionStats: steammessages_clientserver.CMsgClientConnectionStats,
    EMsg.ClientRemoveFriend: steammessages_clientserver_friends.CMsgClientRemoveFriend,
    EMsg.ClientChangeStatus: steammessages_clientserver_friends.CMsgClientChangeStatus,
    EMsg.ClientFriendMsg: steammessages_clientserver_friends.CMsgClientFriendMsg,
    EMsg.ClientRedeemGuestPass: steammessages_clientserver_2.CMsgClientRedeemGuestPass,
    EMsg.ClientGamesPlayedWithDataBlob: steammessages_clientserver.CMsgClientGamesPlayed,
    EMsg.ClientRegisterKey: steammessages_clientserver_2.CMsgClientRegisterKey,
    EMsg.ClientPurchaseWithMachineID: steammessages_clientserver_2.CMsgClientPurchaseWithMachineID,
    EMsg.ClientLogOnResponse: steammessages_clientserver_login.CMsgClientLogonResponse,
    EMsg.ClientLoggedOff: steammessages_clientserver_login.CMsgClientLoggedOff,
    EMsg.ClientPurchaseResponse: steammessages_clientserver_2.CMsgClientPurchaseResponse,
    EMsg.ClientPersonaState: steammessages_clientserver_friends.CMsgClientPersonaState,
    EMsg.ClientFriendsList: steammessages_clientserver_friends.CMsgClientFriendsList,
    EMsg.ClientAccountInfo: steammessages_clientserver_login.CMsgClientAccountInfo,
    EMsg.GSStatusReply: steammessages_clientserver.CMsgGSStatusReply,
    EMsg.ClientGameConnectTokens: steammessages_clientserver.CMsgClientGameConnectTokens,
    EMsg.ClientLicenseList: steammessages_clientserver.CMsgClientLicenseList,
    EMsg.ClientCMList: steammessages_clientserver.CMsgClientCMList,
    EMsg.ClientAddFriend: steammessages_clientserver_friends.CMsgClientAddFriend,
    EMsg.ClientAddFriendResponse: steammessages_clientserver_friends.CMsgClientAddFriendResponse,
    EMsg.ClientChatInvite: steammessages_clientserver.CMsgClientChatInvite,
    EMsg.ClientRequestFriendData: steammessages_clientserver_friends.CMsgClientRequestFriendData,
    EMsg.ClientGetUserStats: steammessages_clientserver.CMsgClientGetUserStats,
    EMsg.ClientGetUserStatsResponse: steammessages_clientserver.CMsgClientGetUserStatsResponse,
    EMsg.ClientStoreUserStats: steammessages_clientserver.CMsgClientStoreUserStats,
    EMsg.ClientStoreUserStatsResponse: steammessages_clientserver.CMsgClientStoreUserStatsResponse,
    EMsg.ClientClanState: steammessages_clientserver.CMsgClientClanState,
    EMsg.ClientServiceModule: steammessages_clientserver_2.CMsgClientServiceModule,
    EMsg.ClientServiceCall: steammessages_clientserver_2.CMsgClientServiceCall,
    EMsg.ClientServiceCallResponse: steammessages_clientserver_2.CMsgClientServiceCallResponse,
    EMsg.ClientGetAppOwnershipTicket: steammessages_clientserver.CMsgClientGetAppOwnershipTicket,
    EMsg.ClientGetAppOwnershipTicketResponse: steammessages_clientserver.CMsgClientGetAppOwnershipTicketResponse,
    EMsg.ClientUpdateUserGameInfo: steammessages_clientserver_2.CMsgClientUpdateUserGameInfo,
    EMsg.ClientTicketAuthComplete: steammessages_clientserver.CMsgClientTicketAuthComplete,
    EMsg.ClientIsLimitedAccount: steammessages_clientserver.CMsgClientIsLimitedAccount,
    EMsg.ClientAuthList: steammessages_clientserver.CMsgClientAuthList,
    EMsg.ClientGetDepotDecryptionKey: steammessages_clientserver_2.CMsgClientGetDepotDecryptionKey,
    EMsg.ClientGetDepotDecryptionKeyResponse: steammessages_clientserver_2.CMsgClientGetDepotDecryptionKeyResponse,
    EMsg.ClientToGC: steammessages_clientserver_2.CMsgGcClient,
    EMsg.ClientFromGC: steammessages_clientserver_2.CMsgGcClient,
    EMsg.ClientEmailAddrInfo: steammessages_clientserver_2.CMsgClientEmailAddrInfo,
    EMsg.ClientNewLoginKey: steammessages_clientserver_login.CMsgClientNewLoginKey,
    EMsg.ClientNewLoginKeyAccepted: steammessages_clientserver_login.CMsgClientNewLoginKeyAccepted,
    EMsg.ClientStoreUserStats2: steammessages_clientserver.CMsgClientStoreUserStats2,
    EMsg.ClientStatsUpdated: steammessages_clientserver.CMsgClientStatsUpdated,
    EMsg.ClientLogon: steammessages_clientserver_login.CMsgClientLogon,
    EMsg.ClientGetClientDetails: steammessages_clientserver.CMsgClientGetClientDetails,
    EMsg.ClientGetClientDetailsResponse: steammessages_clientserver.CMsgClientGetClientDetailsResponse,
    EMsg.ClientReportOverlayDetourFailure: steammessages_clientserver.CMsgClientReportOverlayDetourFailure,
    EMsg.ClientGetClientAppList: steammessages_clientserver.CMsgClientGetClientAppList,
    EMsg.ClientGetClientAppListResponse: steammessages_clientserver.CMsgClientGetClientAppListResponse,
    EMsg.ClientInstallClientApp: steammessages_clientserver.CMsgClientInstallClientApp,
    EMsg.ClientInstallClientAppResponse: steammessages_clientserver.CMsgClientInstallClientAppResponse,
    EMsg.ClientUninstallClientApp: steammessages_clientserver.CMsgClientUninstallClientApp,
    EMsg.ClientUninstallClientAppResponse: steammessages_clientserver.CMsgClientUninstallClientAppResponse,
    EMsg.ClientSetClientAppUpdateState: steammessages_clientserver.CMsgClientSetClientAppUpdateState,
    EMsg.ClientSetClientAppUpdateStateResponse: steammessages_clientserver.CMsgClientSetClientAppUpdateStateResponse,
    EMsg.ClientWalletInfoUpdate: steammessages_clientserver.CMsgClientWalletInfoUpdate,
    EMsg.ClientFriendProfileInfo: steammessages_clientserver_friends.CMsgClientFriendProfileInfo,
    EMsg.ClientFriendProfileInfoResponse: steammessages_clientserver_friends.CMsgClientFriendProfileInfoResponse,
    EMsg.ClientGetCDNAuthToken: steammessages_clientserver_2.CMsgClientGetCdnAuthToken,
    EMsg.ClientGetCDNAuthTokenResponse: steammessages_clientserver_2.CMsgClientGetCdnAuthTokenResponse,
    EMsg.ClientRequestAccountData: steammessages_clientserver_2.CMsgClientRequestAccountData,
    EMsg.ClientRequestAccountDataResponse: steammessages_clientserver_2.CMsgClientRequestAccountDataResponse,
    EMsg.ClientHideFriend: steammessages_clientserver_friends.CMsgClientHideFriend,
    EMsg.ClientFriendsGroupsList: steammessages_clientserver_friends.CMsgClientFriendsGroupsList,
    EMsg.ClientGetClanActivityCounts: steammessages_clientserver_2.CMsgClientGetClanActivityCounts,
    EMsg.ClientGetClanActivityCountsResponse: steammessages_clientserver_2.CMsgClientGetClanActivityCountsResponse,
    EMsg.ClientLogonGameServer: steammessages_clientserver_login.CMsgClientLogon,
    EMsg.ClientItemAnnouncements: steammessages_clientserver_2.CMsgClientItemAnnouncements,
    EMsg.ClientRequestItemAnnouncements: steammessages_clientserver_2.CMsgClientRequestItemAnnouncements,
    EMsg.ClientCommentNotifications: steammessages_clientserver_2.CMsgClientCommentNotifications,
    EMsg.ClientRequestCommentNotifications: steammessages_clientserver_2.CMsgClientRequestCommentNotifications,
    EMsg.ClientFriendUserStatusPublished: steammessages_clientserver_2.CMsgClientFriendUserStatusPublished,
    EMsg.ClientCurrentUIMode: steammessages_clientserver_2.CMsgClientUiMode,
    EMsg.ClientVanityURLChangedNotification: steammessages_clientserver_2.CMsgClientVanityUrlChangedNotification,
    EMsg.ClientUserNotifications: steammessages_clientserver_2.CMsgClientUserNotifications,
    EMsg.BadgeCraftedNotification: steammessages_clientserver_2.CMsgBadgeCraftedNotification,
    EMsg.ClientNetworkingMobileCertRequest: steammessages_clientserver.CMsgClientNetworkingMobileCertRequest,
    EMsg.ClientGMSServerQuery: steammessages_clientserver_2.CMsgClientGmsServerQuery,
    EMsg.GMSClientServerQueryResponse: steammessages_clientserver_2.CMsgGmsClientServerQueryResponse,
    EMsg.GameServerOutOfDate: steammessages_clientserver_2.CMsgGameServerOutOfDate,
    EMsg.ClientInviteToGame: steammessages_clientserver.CMsgClientInviteToGame,
    EMsg.ClientRichPresenceUpload: steammessages_clientserver_2.CMsgClientRichPresenceUpload,
    EMsg.ClientRichPresenceRequest: steammessages_clientserver_2.CMsgClientRichPresenceRequest,
    EMsg.ClientRichPresenceInfo: steammessages_clientserver_2.CMsgClientRichPresenceInfo,
    EMsg.ClientChatOfflineMessageNotification: steammessages_clientserver_2.CMsgClientOfflineMessageNotification,
    EMsg.ClientChatGetFriendMessageHistory: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistory,
    EMsg.ClientChatGetFriendMessageHistoryResponse: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistoryResponse,
    EMsg.ClientChatGetFriendMessageHistoryForOfflineMessages: steammessages_clientserver_2.CMsgClientChatGetFriendMessageHistoryForOfflineMessages,
    EMsg.ClientFSGetFriendsSteamLevels: steammessages_clientserver_2.CMsgClientFsGetFriendsSteamLevels,
    EMsg.ClientFSGetFriendsSteamLevelsResponse: steammessages_clientserver_2.CMsgClientFsGetFriendsSteamLevelsResponse,
    EMsg.ClientPICSChangesSinceRequest: steammessages_clientserver.CMsgClientPICSChangesSinceRequest,
    EMsg.ClientPICSChangesSinceResponse: steammessages_clientserver.CMsgClientPICSChangesSinceResponse,
    EMsg.ClientPICSProductInfoRequest: steammessages_clientserver.CMsgClientPICSProductInfoRequest,
    EMsg.ClientPICSProductInfoResponse: steammessages_clientserver.CMsgClientPICSProductInfoResponse,
    EMsg.ClientPICSAccessTokenRequest: steammessages_clientserver.CMsgClientPICSAccessTokenRequest,
    EMsg.ClientPICSAccessTokenResponse: steammessages_clientserver.CMsgClientPICSAccessTokenResponse,
    EMsg.ClientGetEmoticonList: steammessages_clientserver_friends.CMsgClientGetEmoticonList,
    EMsg.ClientEmoticonList: steammessages_clientserver_friends.CMsgClientEmoticonList,
    EMsg.ClientPlayingSessionState: steammessages_clientserver_2.CMsgClientPlayingSessionState,
    EMsg.ClientKickPlayingSession: steammessages_clientserver_2.CMsgClientKickPlayingSession,
    EMsg.ClientServerTimestampRequest: steammessages_clientserver_login.CMsgClientServerTimestampRequest,
    EMsg.ClientServerTimestampResponse: steammessages_clientserver_login.CMsgClientServerTimestampResponse,
}
